.*Assembler messages:
.*:2: Warning: register alias \$v1 is deprecated, use \$a1 instead
.*:3: Warning: register alias \$fv0 is deprecated, use \$fa0 instead
.*:3: Warning: register alias \$fv1 is deprecated, use \$fa1 instead
.*:3: Warning: register alias \$fv1 is deprecated, use \$fa1 instead
.*:4: Warning: register alias \$v0 is deprecated, use \$a0 instead
.*:4: Warning: register alias \$x is deprecated, use \$r21 instead
